@@ -9,8 +9,26 @@ class Serial(Port):
    def __init__(self, parser, protocolFactory = Protocol):
       super().__init__(parser, portNotOpenError)
       
+      self.__baudrate = 9600
       self.__protocolFactory = protocolFactory
       self.__thread = None
+      self.__timeout = None
+   
+   @property
+   def baudrate(self):
+      return self.__baudrate
+   
+   @baudrate.setter
+   def baudrate(self, baudrate):
+      self.__baudrate = baudrate
+   
+   @property
+   def timeout(self):
+      return self.__timeout
+   
+   @timeout.setter
+   def timeout(self, timeout):
+      self.__timeout = timeout
    
    def isOpen(self):
       return self.__thread and self.__thread.serial.is_open
@@ -24,6 +42,13 @@ class Serial(Port):
       if path is None:
          path = self.path
       
+      for key in ("baudrate", "timeout"):
+         if key in kw:
+            setattr(self, key, kw[key])
+         
+         else:
+            kw[key] = getattr(self, key)
+      
       self.__thread = ReaderThread(self, serial_for_url(path, **kw), self.__protocolFactory)
       
       self.__thread.start()
